@@ -1,25 +1,21 @@
 package Log::Dispatch::Dir;
-BEGIN {
-  $Log::Dispatch::Dir::VERSION = '0.10';
-}
-# ABSTRACT: Log messages to separate files in a directory, with rotate options
 
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '0.13'; # VERSION
 
-use 5.010;
+use 5.010001;
 use warnings;
 use strict;
 use Log::Dispatch::Output;
 use base qw(Log::Dispatch::Output);
 
-use File::Slurp;
+use File::Slurp::Tiny qw(write_file);
 #use File::Stat qw(:stat); # doesn't work in all platforms?
 use Params::Validate qw(validate SCALAR CODEREF);
 use POSIX;
-use Taint::Util;
 
 Params::Validate::validation_options( allow_extra => 1 );
 
-
 sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
@@ -132,7 +128,6 @@ sub _resolve_pattern {
     $res;
 }
 
-
 sub log_message {
     my $self = shift;
     my %p = @_;
@@ -167,7 +162,7 @@ sub _rotate {
     local *DH;
     opendir DH, $self->{dirname};
     while (my $e = readdir DH) {
-        untaint $e;
+        ($e) = $e =~ /(.*)/s; # untaint
         next if $e eq '.' || $e eq '..';
         my @st = stat "$d/$e";
         push @entries, {name => $e, age => ($now-$st[10]), size => $st[7]};
@@ -208,19 +203,22 @@ sub _rotate {
     }
 }
 
-
 1;
+# ABSTRACT: Log messages to separate files in a directory, with rotate options
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Dir - Log messages to separate files in a directory, with rotate options
 
 =head1 VERSION
 
-version 0.10
+This document describes version 0.13 of Log::Dispatch::Dir (from Perl distribution Log-Dispatch-Dir), released on 2015-10-20.
 
 =head1 SYNOPSIS
 
@@ -407,16 +405,31 @@ Log::Dispatch::Output).
 
 L<Log::Dispatch>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Log-Dispatch-Dir>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Log-Dispatch-Dir>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch-Dir>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
